@@ -41,9 +41,7 @@
 #include "xyscanMarkerMaps.h"
 #include "xyscanHelpBrowser.h"
 
-#include <cmath>
 #include <cfloat>
-#include <iostream>
 
 using namespace std;
 
@@ -994,12 +992,12 @@ void xyscanBaseWindow::createToolBox()
     mMeasureItem = new QWidget();
 
     mToolBox->addItem(mPlotAdjustmentItem, QString(tr("Image Info and Adjustment")));
-    mToolBox->addItem(mAxisSettingsItem, QString(tr("Axis Settings")));
+    mToolBox->addItem(mAxisSettingsItem, QString(tr("Marker and Axis Settings")));
     mToolBox->addItem(mErrorScanModeItem, QString(tr("Error Bar Scan Mode")));
     mToolBox->addItem(mCoordinatesItem, QString(tr("Coordinate Display")));
     mToolBox->addItem(mMeasureItem, QString(tr("Measure Tool")));
 
-    mToolBox->setCurrentIndex(1);
+    mToolBox->setCurrentIndex(0);
 
     createAdjustmentToolBoxItem(mPlotAdjustmentItem);
     createAxisSettingsToolBoxItem(mAxisSettingsItem);
