@@ -223,7 +223,7 @@ void xyscanDataTable::resetColumns()
 void xyscanDataTable::toggleTableAlignment()
 {
     static int iMode = 0;
-    int alignMode[3] = {Qt::AlignLeft, Qt::AlignRight, Qt::AlignHCenter};
+    Qt::Alignment alignMode[3] = {Qt::AlignLeft, Qt::AlignRight, Qt::AlignHCenter};
     int irow, icol;
     for (irow=0; irow < rowCount(); irow++) {
         for (icol=0; icol < columnCount(); icol++) {
@@ -490,15 +490,15 @@ void xyscanDataTable::writeRootMacro(QFile& file, const QString& src, bool logx,
     char arrayName[64];
     int nGraphs = max(mXErrorScanCount, mYErrorScanCount);
     for (int i=0; i<nGraphs; i++) {
-        sprintf(arrayName,"dxlow%d", i);
+        snprintf(arrayName, 64,"dxlow%d", i);
         out << "    double " << arrayName << "[" << nrc << "];" << Qt::endl;
-        sprintf(arrayName,"dxup%d", i);
+        snprintf(arrayName, 64,"dxup%d", i);
         out << "    double " << arrayName << "[" << nrc << "];" << Qt::endl;
     }
     for (int i=0; i<nGraphs; i++) {
-        sprintf(arrayName,"dylow%d", i);
+        snprintf(arrayName, 64,"dylow%d", i);
         out << "    double " << arrayName << "[" << nrc << "];" << Qt::endl;
-        sprintf(arrayName,"dyup%d", i);
+        snprintf(arrayName, 64,"dyup%d", i);
         out << "    double " << arrayName << "[" << nrc << "];" << Qt::endl;
     }
 
@@ -512,15 +512,15 @@ void xyscanDataTable::writeRootMacro(QFile& file, const QString& src, bool logx,
         out << "    x[n] = " << x(irow) << ";\t";
         out << "y[n] = " << y(irow) << ";\t";
         for (int i=0; i<nGraphs; i++) {
-            sprintf(arrayName,"dxlow%d", i);
+            snprintf(arrayName, 64,"dxlow%d", i);
             out << arrayName << "[n] = " << dx_lower(irow, i) << ";\t";
-            sprintf(arrayName,"dxup%d", i);
+            snprintf(arrayName, 64,"dxup%d", i);
             out << arrayName << "[n] = " << dx_upper(irow, i) << ";\t";
         }
         for (int i=0; i<nGraphs; i++) {
-            sprintf(arrayName,"dylow%d", i);
+            snprintf(arrayName, 64,"dylow%d", i);
             out << arrayName << "[n] = " << dy_lower(irow, i) << ";\t";
-            sprintf(arrayName,"dyup%d", i);
+            snprintf(arrayName, 64,"dyup%d", i);
             out << arrayName << "[n] = " << dy_upper(irow, i) << ";\t";
         }
         out << "n++;" << Qt::endl;
@@ -536,8 +536,8 @@ void xyscanDataTable::writeRootMacro(QFile& file, const QString& src, bool logx,
     char graphName[64];
     int icolor = 1;
     for (int i=0; i<nGraphs; i++) {
-        sprintf(graphName,"xyscan%d", i);
-        sprintf(arrayName,"dxlow%d, dxup%d, dylow%d, dyup%d", i, i, i, i);
+        snprintf(graphName, 64,"xyscan%d", i);
+        snprintf(arrayName, 64,"dxlow%d, dxup%d, dylow%d, dyup%d", i, i, i, i);
         out << "    TGraphAsymmErrors *" << graphName << " = new TGraphAsymmErrors(n, x, y, " << arrayName << ");" << Qt::endl;
         out << "    " << graphName << "->SetMarkerColor(1);" << Qt::endl;
         if (i==0) {
@@ -554,7 +554,7 @@ void xyscanDataTable::writeRootMacro(QFile& file, const QString& src, bool logx,
         }
     }
     if (nGraphs == 0) {
-        sprintf(graphName,"xyscanGraph");
+        snprintf(graphName, 64,"xyscanGraph");
         out << "    TGraph *" << graphName << " = new TGraph(n, x, y);" << Qt::endl;
         out << "    " << graphName << "->SetMarkerStyle(20);" << Qt::endl;
         out << "    " << graphName << "->SetLineColor(1);" << Qt::endl;
