@@ -14,8 +14,6 @@
 #include <QUrl>
 #include <QMimeData>
 #include "xyscanGraphicsView.h"
-#include <iostream>
-using namespace std;
 
 xyscanGraphicsView::xyscanGraphicsView (QWidget* parent) : QGraphicsView(parent)
 {
