@@ -118,9 +118,9 @@ xyscanWindow::xyscanWindow()
     //
     //  Shortcuts (for developer only)
     //
-    QShortcut *mCalibrationLinPlotShortcut = new QShortcut(QKeySequence(tr("Ctrl+Shift+C")), this);
+    QShortcut *mCalibrationLinPlotShortcut = new QShortcut(QKeySequence(tr("Ctrl+Shift+Left")), this);
     connect(mCalibrationLinPlotShortcut, &QShortcut::activated, [=](){this->loadCalibrationPlot(false);});
-    QShortcut *mCalibrationLogPlotShortcut = new QShortcut(QKeySequence(tr("Ctrl+Shift+L")), this);
+    QShortcut *mCalibrationLogPlotShortcut = new QShortcut(QKeySequence(tr("Ctrl+Shift+Right")), this);
     connect(mCalibrationLogPlotShortcut, &QShortcut::activated, [=](){this->loadCalibrationPlot(true);});
 
     //
@@ -1484,11 +1484,11 @@ bool xyscanWindow::readyForScan()
     bool OK;
     bool allMarkers = (numberOfMarkersSet() == 4);
     bool allAxisValues = true;
-    double val;
-    val = locale.toDouble(mLowerXValueField->text(), &OK); if (!OK) allAxisValues = false;
-    val = locale.toDouble(mUpperXValueField->text(), &OK); if (!OK) allAxisValues = false;
-    val = locale.toDouble(mLowerYValueField->text(), &OK); if (!OK) allAxisValues = false;
-    val = locale.toDouble(mUpperYValueField->text(), &OK); if (!OK) allAxisValues = false;
+
+    ignore = locale.toDouble(mLowerXValueField->text(), &OK); if (!OK) allAxisValues = false;
+    ignore = locale.toDouble(mUpperXValueField->text(), &OK); if (!OK) allAxisValues = false;
+    ignore = locale.toDouble(mLowerYValueField->text(), &OK); if (!OK) allAxisValues = false;
+    ignore = locale.toDouble(mUpperYValueField->text(), &OK); if (!OK) allAxisValues = false;
     if (allMarkers && allAxisValues)
         return true;
     else
@@ -1497,8 +1497,6 @@ bool xyscanWindow::readyForScan()
 
 void xyscanWindow::resetMarker()
 {
-    QLocale local;
-    
     mMarker[mXLower]->setVisible(false);    
     mMarker[mXUpper]->setVisible(false);    
     mMarker[mYLower]->setVisible(false);    
